#!/bin/sh
#
# install.sh - installer for MythTV channel icons for Australia
#
# Copyright (c) 1992-2012 Lighterra - Open Source (MPL & LGPL)
#
# written by Jason Robert Carey Patterson <jason@lighterra.com>
#

CONFIGDIR="$HOME/.mythtv"
ICONDIR="$CONFIGDIR/channels"
OWNER=`id -un`:`id -gn`
CACHEDIR=/var/cache/mythweb/image_cache

PATH="$PATH:/usr/bin:/bin" export PATH
set -e
umask 022

install()
{
    echo "installing $2"
    mkdir -p -m 755 "`dirname \"$2\"`"
    tmpfile="$2.$$"
    trap "rm -f '$tmpfile'" 0 1 2 3 15
    rm -f "$tmpfile"
    cp -f "$1" "$tmpfile"
    chmod $3 "$tmpfile"
    chown $OWNER "$tmpfile"
    mv -f "$tmpfile" "$2"
    trap "" 0 1 2 3 15
}

case "$0" in */*) cd "`dirname \"$0\"`" ;; esac

if [ -r COPYRIGHT.txt ]; then cat COPYRIGHT.txt; fi

for icon in *.png; do
    install "$icon" "$ICONDIR/$icon" 644
done

echo "setting icons in MythTV MySQL database channel table..."
mysql mythconverg << EOF
    UPDATE channel SET icon = "$ICONDIR/ABC-1.png"       WHERE channum =  2;
    UPDATE channel SET icon = "$ICONDIR/ABC-1.png"       WHERE channum = 20;
    UPDATE channel SET icon = "$ICONDIR/ABC-1.png"       WHERE channum = 21;
    UPDATE channel SET icon = "$ICONDIR/ABC-2.png"       WHERE channum = 22;
    UPDATE channel SET icon = "$ICONDIR/ABC-3.png"       WHERE channum = 23;
    UPDATE channel SET icon = "$ICONDIR/ABC-News-24.png" WHERE channum = 24;
    UPDATE channel SET icon = "$ICONDIR/SBS-One.png"     WHERE channum =  3;
    UPDATE channel SET icon = "$ICONDIR/SBS-One.png"     WHERE channum = 30;
    UPDATE channel SET icon = "$ICONDIR/SBS-Two.png"     WHERE channum = 32;
    UPDATE channel SET icon = "$ICONDIR/7.png"           WHERE channum =  7;
    UPDATE channel SET icon = "$ICONDIR/7.png"           WHERE channum = 70;
    UPDATE channel SET icon = "$ICONDIR/7-Two.png"       WHERE channum = 72;
    UPDATE channel SET icon = "$ICONDIR/7-Two.png"       WHERE channum = 62;
    UPDATE channel SET icon = "$ICONDIR/7mate.png"       WHERE channum = 73;
    UPDATE channel SET icon = "$ICONDIR/7mate.png"       WHERE channum = 63;
    UPDATE channel SET icon = "$ICONDIR/4Me.png"         WHERE channum = 74;
    UPDATE channel SET icon = "$ICONDIR/4Me.png"         WHERE channum = 64;
    UPDATE channel SET icon = "$ICONDIR/9.png"           WHERE channum =  9;
    UPDATE channel SET icon = "$ICONDIR/Gem.png"         WHERE channum = 90;
    UPDATE channel SET icon = "$ICONDIR/Gem.png"         WHERE channum = 80;
    UPDATE channel SET icon = "$ICONDIR/Go.png"          WHERE channum = 99;
    UPDATE channel SET icon = "$ICONDIR/Go.png"          WHERE channum = 88;
    UPDATE channel SET icon = "$ICONDIR/eXtra.png"       WHERE channum = 94;
    UPDATE channel SET icon = "$ICONDIR/eXtra.png"       WHERE channum = 84;
    UPDATE channel SET icon = "$ICONDIR/Ten.png"         WHERE channum = 10;
    UPDATE channel SET icon = "$ICONDIR/One.png"         WHERE channum =  1;
    UPDATE channel SET icon = "$ICONDIR/One.png"         WHERE channum = 12;
    UPDATE channel SET icon = "$ICONDIR/One.png"         WHERE channum = 50;
    UPDATE channel SET icon = "$ICONDIR/11.png"          WHERE channum = 11;
    UPDATE channel SET icon = "$ICONDIR/11.png"          WHERE channum = 55;
    UPDATE channel SET icon = "$ICONDIR/Prime.png"       WHERE channum =  6;
    UPDATE channel SET icon = "$ICONDIR/Prime.png"       WHERE channum = 60;
    UPDATE channel SET icon = "$ICONDIR/NBN.png"         WHERE channum =  8;
    UPDATE channel SET icon = "$ICONDIR/SC-Ten.png"      WHERE channum =  5;
EOF
echo "done."

echo "installation completed successfully."

if [ -d "$CACHEDIR" ]; then
    echo "you may also want to delete any old files in $CACHEDIR."
fi
